@@ -21,15 +21,17 @@
 #include "device_quirks.h"
 
 #include <string>
+#include <memory>
 
 namespace repowerd
 {
 class Log;
+class DeviceInfo;
 
 class AndroidDeviceQuirks : public DeviceQuirks
 {
 public:
-    AndroidDeviceQuirks(Log& log);
+    AndroidDeviceQuirks(Log& log, std::shared_ptr<DeviceInfo> const& device_info);
 
     std::chrono::milliseconds synthetic_initial_proximity_event_delay() const override;
     ProximityEventType synthetic_initial_proximity_event_type() const override;
