@@ -23,7 +23,11 @@
 #include <ctime>
 #include <string>
 
-void repowerd::ConsoleLog::log(char const* tag, char const* format, ...)
+repowerd::ConsoleLog::ConsoleLog(repowerd::LogLevel threshold) : repowerd::Log::Log(threshold)
+{
+}
+
+void repowerd::ConsoleLog::logOutput(repowerd::LogLevel level, char const* tag, char const* format, va_list ap)
 {
     struct timespec ts;
     clock_gettime(CLOCK_REALTIME, &ts);
@@ -38,15 +42,21 @@ void repowerd::ConsoleLog::log(char const* tag, char const* format, ...)
     format_str += "] ";
     format_str += tag;
     format_str += ": ";
+    switch (level) {
+    case LogLevel::Warning:
+        format_str += "WARNING";
+        break;
+    case LogLevel::Info:
+        format_str += "INFO";
+        break;
+    default:
+        format_str += "DEBUG";
+    }
+    format_str += ": ";
     format_str += format;
     format_str += "\n";
 
-    va_list ap;
-    va_start(ap, format);
-
     vprintf(format_str.c_str(), ap);
 
-    va_end(ap);
-
     fflush(stdout);
 }
