@@ -26,7 +26,8 @@ namespace repowerd
 class ConsoleLog : public Log
 {
 public:
-    void log(char const* tag, char const* format, ...) override;
+    ConsoleLog(LogLevel threshold);
+    void logOutput(LogLevel level, char const* tag, char const* format, va_list ap) override;
 };
 
 }
