@@ -18,6 +18,10 @@
 
 #include "null_log.h"
 
-void repowerd::NullLog::log(char const*, char const*, ...)
+repowerd::NullLog::NullLog(repowerd::LogLevel threshold) : repowerd::Log::Log(threshold)
+{
+}
+
+void repowerd::NullLog::logOutput(repowerd::LogLevel, char const*, char const*, va_list)
 {
 }
