@@ -24,3 +24,8 @@ void repowerd::RealChrono::sleep_for(std::chrono::nanoseconds t)
 {
     std::this_thread::sleep_for(t);
 }
+
+std::chrono::steady_clock::time_point repowerd::RealChrono::steady_now()
+{
+    return std::chrono::steady_clock::now();
+}
\ No newline at end of file
