@@ -26,10 +26,10 @@ namespace repowerd
 class SyslogLog : public Log
 {
 public:
-    SyslogLog();
+    SyslogLog(LogLevel threshold);
     ~SyslogLog();
 
-    void log(char const* tag, char const* format, ...) override;
+    void logOutput(LogLevel level, char const* tag, char const* format, va_list ap) override;
 };
 
 }
