@@ -24,6 +24,7 @@
 #include "temporary_suspend_inhibition.h"
 #include "wakeup_service.h"
 
+#include "src/core/double_tap_to_wake.h"
 #include "src/core/infinite_timeout.h"
 #include "src/core/log.h"
 
@@ -106,6 +107,15 @@ char const* const unity_screen_service_introspection = R"(<!DOCTYPE node PUBLIC
     <method name='setTouchVisualizationEnabled'>
       <arg name='enabled' type='b' direction='in'/>
     </method>
+    <method name='getDoubleTapToWakeEnabled'>
+      <arg type='b' name='enable' direction='out' />
+    </method>
+    <method name='getDoubleTapToWakeSupported'>
+      <arg type='b' name='supported' direction='out' />
+    </method>
+    <method name='setDoubleTapToWakeEnabled'>
+      <arg type='b' name='enable' direction='in' />
+    </method>
     <signal name='DisplayPowerStateChange'>
       <arg name='state' type='i'/>
       <arg name='reason' type='i'/>
@@ -128,6 +138,9 @@ char const* const dbus_repowerd_service_introspection = R"(
     <method name='clearSysState'>
       <arg type='s' name='cookie' direction='in' />
     </method>
+    <method name='listSysRequests'>
+      <arg type='a{sv}' name='sys_requests' direction='out' />
+    </method>
     <method name='requestWakeup'>
       <arg type='s' name='name' direction='in' />
       <arg type='t' name='time' direction='in' />
@@ -137,7 +150,7 @@ char const* const dbus_repowerd_service_introspection = R"(
       <arg type='s' name='cookie' direction='in' />
     </method>
     <method name='getBrightnessParams'>
-      <!-- Returns dim, min, max, and default brighness and whether or not
+      <!-- Returns dim, min, max, and default brightness and whether or not
            autobrightness is supported, in that order -->
       <arg type='(iiiib)' name='params' direction="out" />
     </method>
@@ -158,12 +171,14 @@ repowerd::UnityScreenService::UnityScreenService(
     std::shared_ptr<BrightnessNotification> const& brightness_notification,
     std::shared_ptr<Log> const& log,
     std::shared_ptr<TemporarySuspendInhibition> const& temporary_suspend_inhibition,
+    std::shared_ptr<DoubleTapToWake> const& double_tap_to_wake_control,
     DeviceConfig const& device_config,
     std::string const& dbus_bus_address)
     : wakeup_service{wakeup_service},
       brightness_notification{brightness_notification},
       temporary_suspend_inhibition{temporary_suspend_inhibition},
       log{log},
+      double_tap_to_wake_control{double_tap_to_wake_control},
       dbus_connection{dbus_bus_address},
       dbus_event_loop{"DBusService"},
       disable_inactivity_timeout_handler{null_arg2_handler},
@@ -477,6 +492,10 @@ void repowerd::UnityScreenService::dbus_method_call(
 
         g_dbus_method_invocation_return_value(invocation, NULL);
     }
+    else if (method_name == "listSysRequests")
+    {
+        g_dbus_method_invocation_return_value(invocation, dbus_listSysRequests());
+    }
     else if (method_name == "requestWakeup")
     {
         char const* name{""};
@@ -510,6 +529,29 @@ void repowerd::UnityScreenService::dbus_method_call(
                 params.default_value,
                 params.autobrightness_supported));
     }
+    else if (method_name == "getDoubleTapToWakeEnabled")
+    {
+        auto enabled = dbus_getDoubleTapToWakeEnabled();
+
+        g_dbus_method_invocation_return_value(
+            invocation, g_variant_new("(b)", enabled));
+    }
+    else if (method_name == "getDoubleTapToWakeSupported")
+    {
+        auto supported = dbus_getDoubleTapToWakeSupported();
+
+        g_dbus_method_invocation_return_value(
+            invocation, g_variant_new("(b)", supported));
+    }
+    else if (method_name == "setDoubleTapToWakeEnabled")
+    {
+        gboolean enable{FALSE};
+        g_variant_get(parameters, "(b)", &enable);
+
+        dbus_setDoubleTapToWakeEnabled(enable == TRUE);
+
+        g_dbus_method_invocation_return_value(invocation, NULL);
+    }
     else
     {
         dbus_unknown_method(sender, method_name);
@@ -549,13 +591,14 @@ void repowerd::UnityScreenService::dbus_signal(
 int32_t repowerd::UnityScreenService::dbus_keepDisplayOn(
     std::string const& sender, pid_t pid)
 {
-    log->log(log_tag, "dbus_keepDisplayOn(%s)", sender.c_str());
+    log->logDebug(log_tag, "dbus_keepDisplayOn(%s)", sender.c_str());
 
     auto const id = next_keep_display_on_id++;
-    keep_display_on_ids.emplace(sender, id);
+    keep_display_on_data_t d = {id, pid};
+    keep_display_on_ids.emplace(sender, d);
     disable_inactivity_timeout_handler(std::to_string(id), pid);
 
-    log->log(log_tag, "dbus_keepDisplayOn(%s) => %d", sender.c_str(), id);
+    log->logDebug(log_tag, "dbus_keepDisplayOn(%s) => %d", sender.c_str(), id);
 
     return id;
 }
@@ -563,7 +606,7 @@ int32_t repowerd::UnityScreenService::dbus_keepDisplayOn(
 void repowerd::UnityScreenService::dbus_removeDisplayOnRequest(
     std::string const& sender, int32_t id, pid_t pid)
 {
-    log->log(log_tag, "dbus_removeDisplayOnRequest(%s,%d)", sender.c_str(), id);
+    log->logDebug(log_tag, "dbus_removeDisplayOnRequest(%s,%d)", sender.c_str(), id);
 
     bool id_removed{false};
 
@@ -572,7 +615,7 @@ void repowerd::UnityScreenService::dbus_removeDisplayOnRequest(
          iter != range.second;
          ++iter)
     {
-        if (iter->second == id)
+        if (iter->second.id == id)
         {
             keep_display_on_ids.erase(iter);
             id_removed = true;
@@ -593,7 +636,7 @@ void repowerd::UnityScreenService::dbus_NameOwnerChanged(
         request_sys_state_ids.find(name) != request_sys_state_ids.end() ||
         active_notifications.find(name) != active_notifications.end())
     {
-        log->log(log_tag, "dbus_NameOwnerChanged(%s,%s,%s)",
+        log->logDebug(log_tag, "dbus_NameOwnerChanged(%s,%s,%s)",
                  name.c_str(), old_owner.c_str(), new_owner.c_str());
     }
 
@@ -601,12 +644,12 @@ void repowerd::UnityScreenService::dbus_NameOwnerChanged(
     {
         auto const kdo_range = keep_display_on_ids.equal_range(name);
         for (auto iter = kdo_range.first; iter != kdo_range.second; ++iter)
-            enable_inactivity_timeout_handler(std::to_string(iter->second), 0);
+            enable_inactivity_timeout_handler(std::to_string(iter->second.id), 0);
         keep_display_on_ids.erase(name);
 
         auto rss_range = request_sys_state_ids.equal_range(name);
         for (auto iter = rss_range.first; iter != rss_range.second; ++iter)
-            allow_suspend_handler(std::to_string(iter->second), 0);
+            allow_suspend_handler(std::to_string(iter->second.id), 0);
         request_sys_state_ids.erase(name);
 
         auto const num_notifications_removed = active_notifications.erase(name);
@@ -618,7 +661,7 @@ void repowerd::UnityScreenService::dbus_NameOwnerChanged(
 void repowerd::UnityScreenService::dbus_userAutobrightnessEnable(
     bool enable, pid_t pid)
 {
-    log->log(log_tag, "dbus_userAutobrightnessEnable(%s)",
+    log->logDebug(log_tag, "dbus_userAutobrightnessEnable(%s)",
              enable ? "enable" : "disable");
 
     if (enable)
@@ -630,7 +673,7 @@ void repowerd::UnityScreenService::dbus_userAutobrightnessEnable(
 void repowerd::UnityScreenService::dbus_setUserBrightness(
     int32_t brightness, pid_t pid)
 {
-    log->log(log_tag, "dbus_setUserBrightness(%d)", brightness);
+    log->logDebug(log_tag, "dbus_setUserBrightness(%d)", brightness);
 
     set_normal_brightness_value_handler(
         brightness/static_cast<double>(brightness_params.max_value),
@@ -640,7 +683,7 @@ void repowerd::UnityScreenService::dbus_setUserBrightness(
 void repowerd::UnityScreenService::dbus_setInactivityTimeouts(
     int32_t poweroff_timeout, int32_t dimmer_timeout, pid_t pid)
 {
-    log->log(log_tag, "dbus_setInactivityTimeouts(%d,%d)",
+    log->logDebug(log_tag, "dbus_setInactivityTimeouts(%d,%d)",
              poweroff_timeout, dimmer_timeout);
 
     if (poweroff_timeout < 0) return;
@@ -653,7 +696,7 @@ void repowerd::UnityScreenService::dbus_setInactivityTimeouts(
 bool repowerd::UnityScreenService::dbus_setScreenPowerMode(
     std::string const& sender, std::string const& mode, int32_t reason, pid_t pid)
 {
-    log->log(log_tag, "dbus_setScreenPowerMode(%s,%s,%d)",
+    log->logDebug(log_tag, "dbus_setScreenPowerMode(%s,%s,%d)",
              sender.c_str(), mode.c_str(), reason);
 
     if (reason == static_cast<int32_t>(UnityScreenPowerStateChangeReason::notification) ||
@@ -662,7 +705,8 @@ bool repowerd::UnityScreenService::dbus_setScreenPowerMode(
         if (mode == "on")
         {
             auto const id = notification_id(sender, active_notifications.count(sender));
-            active_notifications.emplace(sender);
+            active_notification_t d = {pid, reason};
+            active_notifications.emplace(sender, d);
             notification_handler(id, pid);
         }
         else if (mode == "off")
@@ -684,7 +728,7 @@ bool repowerd::UnityScreenService::dbus_setScreenPowerMode(
 void repowerd::UnityScreenService::dbus_emit_DisplayPowerStateChange(
     int32_t power_state, int32_t reason)
 {
-    log->log(log_tag, "dbus_emit_DisplayPowerStateChange(%d,%d)",
+    log->logDebug(log_tag, "dbus_emit_DisplayPowerStateChange(%d,%d)",
              power_state, reason);
 
     g_dbus_connection_emit_signal(
@@ -703,7 +747,7 @@ std::string repowerd::UnityScreenService::dbus_requestSysState(
     int32_t state,
     pid_t pid)
 {
-    log->log(log_tag, "dbus_requestSysState(%s,%s,%d)",
+    log->logDebug(log_tag, "dbus_requestSysState(%s,%s,%d)",
              sender.c_str(), name.c_str(), state);
 
     int32_t const active_state{1};
@@ -712,11 +756,12 @@ std::string repowerd::UnityScreenService::dbus_requestSysState(
         throw std::runtime_error{"Invalid state"};
 
     auto const id = next_request_sys_state_id++;
-    request_sys_state_ids.emplace(sender, id);
+    request_sys_state_data_t d = {id, pid, name};
+    request_sys_state_ids.emplace(sender, d);
 
     disallow_suspend_handler(std::to_string(id), pid);
 
-    log->log(log_tag, "dbus_requestSysState(%s,%s,%d) => %d",
+    log->logDebug(log_tag, "dbus_requestSysState(%s,%s,%d) => %d",
              sender.c_str(), name.c_str(), state, id);
 
     return std::to_string(id);
@@ -727,7 +772,7 @@ void repowerd::UnityScreenService::dbus_clearSysState(
     std::string const& cookie,
     pid_t pid)
 {
-    log->log(log_tag, "dbus_clearSysState(%s,%s)",
+    log->logDebug(log_tag, "dbus_clearSysState(%s,%s)",
              sender.c_str(), cookie.c_str());
 
     bool id_removed{false};
@@ -740,7 +785,7 @@ void repowerd::UnityScreenService::dbus_clearSysState(
          iter != range.second;
          ++iter)
     {
-        if (iter->second == id)
+        if (iter->second.id == id)
         {
             request_sys_state_ids.erase(iter);
             id_removed = true;
@@ -752,18 +797,97 @@ void repowerd::UnityScreenService::dbus_clearSysState(
         allow_suspend_handler(std::to_string(id), pid);
 }
 
+GVariant *repowerd::UnityScreenService::dbus_listSysRequests()
+{
+    GVariant *ret_tuple[1];
+    GVariant *dict_entries[3];
+
+    GVariant **array_entries = new GVariant*[request_sys_state_ids.size()];
+    {
+        auto itr = request_sys_state_ids.begin();
+        int i = 0;
+        for(; itr != request_sys_state_ids.end(); itr++, i++){
+            GVariant *tuple[4];
+            tuple[0] = g_variant_new_string(itr->first.c_str());
+            tuple[1] = g_variant_new_int32(itr->second.id);
+            tuple[2] = g_variant_new_uint64(itr->second.pid);
+            tuple[3] = g_variant_new_string(itr->second.name.c_str());
+            array_entries[i] =
+                g_variant_new_tuple(tuple, sizeof(tuple) / sizeof(GVariant *));
+        }
+        auto gvt = g_variant_type_new("(sits)");
+        auto request_sys_state_array =
+            g_variant_new_array(gvt, array_entries, request_sys_state_ids.size());
+        g_variant_type_free(gvt);
+        dict_entries[0] =
+            g_variant_new_dict_entry(g_variant_new_string("request_sys_state"),
+                g_variant_new_variant(request_sys_state_array));
+    }
+    delete [] array_entries;
+
+    array_entries = new GVariant*[keep_display_on_ids.size()];
+    {
+        auto itr = keep_display_on_ids.begin();
+        int i = 0;
+        for(; itr != keep_display_on_ids.end(); itr++, i++){
+            GVariant *tuple[3];
+            tuple[0] = g_variant_new_string(itr->first.c_str());
+            tuple[1] = g_variant_new_int32(itr->second.id);
+            tuple[2] = g_variant_new_uint64(itr->second.pid);
+            array_entries[i] =
+                g_variant_new_tuple(tuple, sizeof(tuple) / sizeof(GVariant *));
+        }
+        auto gvt = g_variant_type_new("(sit)");
+        auto keep_display_on_array =
+            g_variant_new_array(gvt, array_entries, keep_display_on_ids.size());
+        g_variant_type_free(gvt);
+        dict_entries[1] =
+            g_variant_new_dict_entry(g_variant_new_string("keep_display_on"),
+                g_variant_new_variant(keep_display_on_array));
+    }
+    delete [] array_entries;
+
+    array_entries = new GVariant*[active_notifications.size()];
+    {
+        auto itr = active_notifications.begin();
+        int i = 0;
+        for(; itr != active_notifications.end(); itr++, i++){
+            GVariant *tuple[3];
+            tuple[0] = g_variant_new_string(itr->first.c_str());
+            tuple[1] = g_variant_new_uint64(itr->second.pid);
+            tuple[2] = g_variant_new_int32(itr->second.reason);
+            array_entries[i] =
+                g_variant_new_tuple(tuple, sizeof(tuple) / sizeof(GVariant *));
+        }
+        auto gvt = g_variant_type_new("(sti)");
+        auto active_notifications_array =
+            g_variant_new_array(gvt, array_entries, active_notifications.size());
+        g_variant_type_free(gvt);
+        dict_entries[2] =
+            g_variant_new_dict_entry(g_variant_new_string("active_notifications"),
+                g_variant_new_variant(active_notifications_array));
+    }
+    delete [] array_entries;
+
+    auto gvt = g_variant_type_new("{sv}");
+    ret_tuple[0] =
+        g_variant_new_array(gvt, dict_entries, sizeof(dict_entries) / sizeof(GVariant *));
+    g_variant_type_free(gvt);
+    return g_variant_new_tuple(ret_tuple, 1);
+}
+
 std::string repowerd::UnityScreenService::dbus_requestWakeup(
     std::string const& sender,
     std::string const& name,
     uint64_t time)
 {
-    log->log(log_tag, "dbus_requestWakeup(%s,%s,%ju)",
+    log->logDebug(log_tag, "dbus_requestWakeup(%s,%s,%ju)",
              sender.c_str(), name.c_str(), static_cast<uintmax_t>(time));
 
     auto const cookie =
         wakeup_service->schedule_wakeup_at(std::chrono::system_clock::from_time_t(time));
 
-    log->log(log_tag, "dbus_requestWakeup(%s,%s,%ju) => %s",
+    log->logDebug(log_tag, "dbus_requestWakeup(%s,%s,%ju) => %s",
              sender.c_str(), name.c_str(), static_cast<uintmax_t>(time), cookie.c_str());
 
     return cookie;
@@ -772,14 +896,14 @@ std::string repowerd::UnityScreenService::dbus_requestWakeup(
 void repowerd::UnityScreenService::dbus_clearWakeup(
     std::string const& sender, std::string const& cookie)
 {
-    log->log(log_tag, "dbus_clearWakeup(%s,%s)", sender.c_str(), cookie.c_str());
+    log->logDebug(log_tag, "dbus_clearWakeup(%s,%s)", sender.c_str(), cookie.c_str());
 
     wakeup_service->cancel_wakeup(cookie);
 }
 
 repowerd::BrightnessParams repowerd::UnityScreenService::dbus_getBrightnessParams()
 {
-    log->log(log_tag, "dbus_getBrightnessParams() => (%d,%d,%d,%d,%s)",
+    log->logDebug(log_tag, "dbus_getBrightnessParams() => (%d,%d,%d,%d,%s)",
              brightness_params.dim_value,
              brightness_params.min_value,
              brightness_params.max_value,
@@ -791,7 +915,7 @@ repowerd::BrightnessParams repowerd::UnityScreenService::dbus_getBrightnessParam
 
 void repowerd::UnityScreenService::dbus_emit_Wakeup()
 {
-    log->log(log_tag, "dbus_emit_Wakeup()");
+    log->logDebug(log_tag, "dbus_emit_Wakeup()");
 
     g_dbus_connection_emit_signal(
         dbus_connection,
@@ -807,7 +931,7 @@ void repowerd::UnityScreenService::dbus_emit_brightness(double brightness)
 {
     int32_t const brightness_abs = round(brightness * brightness_params.max_value);
 
-    log->log(log_tag, "dbus_emit_brightness(%f), brightness_value=%d",
+    log->logDebug(log_tag, "dbus_emit_brightness(%f), brightness_value=%d",
              brightness, brightness_abs);
 
     g_dbus_connection_emit_signal(
@@ -822,10 +946,35 @@ void repowerd::UnityScreenService::dbus_emit_brightness(double brightness)
         nullptr);
 }
 
+bool repowerd::UnityScreenService::dbus_getDoubleTapToWakeEnabled()
+{
+    log->logDebug(log_tag, "dbus_getDoubleTapToWakeEnabled()");
+
+    return double_tap_to_wake_control->is_enabled();
+}
+
+bool repowerd::UnityScreenService::dbus_getDoubleTapToWakeSupported()
+{
+    log->logDebug(log_tag, "dbus_getDoubleTapToWakeSupported()");
+
+    return double_tap_to_wake_control->is_supported();
+}
+
+void repowerd::UnityScreenService::dbus_setDoubleTapToWakeEnabled(bool enable)
+{
+    log->logDebug(log_tag, "dbus_setDoubleTapToWakeEnabled(%s)",
+             enable ? "enable" : "disable");
+
+    if (enable)
+        double_tap_to_wake_control->enable();
+    else
+        double_tap_to_wake_control->disable();
+}
+
 void repowerd::UnityScreenService::dbus_unknown_method(
     std::string const& sender, std::string const& name)
 {
-    log->log(log_tag, "dbus_unknown_method(%s,%s)", sender.c_str(), name.c_str());
+    log->logWarning(log_tag, "dbus_unknown_method(%s,%s)", sender.c_str(), name.c_str());
 }
 
 pid_t repowerd::UnityScreenService::dbus_get_invocation_sender_pid(
@@ -851,7 +1000,7 @@ pid_t repowerd::UnityScreenService::dbus_get_invocation_sender_pid(
 
     if (!result)
     {
-        log->log(log_tag, "failed to get pid of '%s': %s",
+        log->logWarning(log_tag, "failed to get pid of '%s': %s",
                  sender, error.message_str().c_str());
         return -1;
     }
