@@ -126,21 +126,21 @@ void repowerd::DefaultStateMachine::handle_alarm(AlarmId id)
 {
     if (id == power_button_long_press_alarm_id)
     {
-        log->log(log_tag, "handle_alarm(long_press)");
+        log->logDebug(log_tag, "handle_alarm(long_press)");
         power_button_event_sink->notify_long_press();
         power_button_long_press_detected = true;
         power_button_long_press_alarm_id = AlarmId::invalid;
     }
     else if (id == user_inactivity_display_dim_alarm_id)
     {
-        log->log(log_tag, "handle_alarm(display_dim)");
+        log->logDebug(log_tag, "handle_alarm(display_dim)");
         user_inactivity_display_dim_alarm_id = AlarmId::invalid;
         if (is_inactivity_timeout_application_allowed())
             dim_display();
     }
     else if (id == user_inactivity_display_off_alarm_id)
     {
-        log->log(log_tag, "handle_alarm(display_off)");
+        log->logDebug(log_tag, "handle_alarm(display_off)");
         user_inactivity_display_off_alarm_id = AlarmId::invalid;
         if (is_inactivity_timeout_application_allowed())
             turn_off_display(DisplayPowerChangeReason::activity);
@@ -148,20 +148,20 @@ void repowerd::DefaultStateMachine::handle_alarm(AlarmId id)
     }
     else if (id == user_inactivity_suspend_alarm_id)
     {
-        log->log(log_tag, "handle_alarm(suspend)");
+        log->logDebug(log_tag, "handle_alarm(suspend)");
         user_inactivity_suspend_alarm_id = AlarmId::invalid;
         if (is_inactivity_timeout_application_allowed())
             suspend_when_allowed();
     }
     else if (id == proximity_disable_alarm_id)
     {
-        log->log(log_tag, "handle_alarm(proximity_disable)");
+        log->logDebug(log_tag, "handle_alarm(proximity_disable)");
         proximity_disable_alarm_id = AlarmId::invalid;
         disable_proximity(ProximityEnablement::until_far_event_or_timeout);
     }
     else if (id == notification_expiration_alarm_id)
     {
-        log->log(log_tag, "handle_alarm(notification_expiration)");
+        log->logDebug(log_tag, "handle_alarm(notification_expiration)");
         notification_expiration_alarm_id = AlarmId::invalid;
         if (display_power_mode == DisplayPowerMode::on)
             schedule_immediate_user_inactivity_alarm();
@@ -171,7 +171,7 @@ void repowerd::DefaultStateMachine::handle_alarm(AlarmId id)
     }
     else if (id == suspend_delay_alarm_id)
     {
-        log->log(log_tag, "handle_alarm(suspend_delay)");
+        log->logDebug(log_tag, "handle_alarm(suspend_delay)");
         suspend_delay_alarm_id = AlarmId::invalid;
         if (display_power_mode == DisplayPowerMode::off &&
                 display_power_mode_reason != DisplayPowerChangeReason::proximity &&
@@ -183,7 +183,7 @@ void repowerd::DefaultStateMachine::handle_alarm(AlarmId id)
 
 void repowerd::DefaultStateMachine::handle_active_call()
 {
-    log->log(log_tag, "handle_active_call");
+    log->logDebug(log_tag, "handle_active_call");
 
     if (display_power_mode == DisplayPowerMode::on)
     {
@@ -200,7 +200,7 @@ void repowerd::DefaultStateMachine::handle_active_call()
 
 void repowerd::DefaultStateMachine::handle_no_active_call()
 {
-    log->log(log_tag, "handle_no_active_call");
+    log->logDebug(log_tag, "handle_no_active_call");
 
     if (display_power_mode == DisplayPowerMode::on)
     {
@@ -225,14 +225,14 @@ void repowerd::DefaultStateMachine::handle_no_active_call()
 
 void repowerd::DefaultStateMachine::handle_enable_inactivity_timeout()
 {
-    log->log(log_tag, "handle_enable_inactivity_timeout");
+    log->logDebug(log_tag, "handle_enable_inactivity_timeout");
 
     allow_inactivity_timeout(InactivityTimeoutAllowance::client);
 }
 
 void repowerd::DefaultStateMachine::handle_disable_inactivity_timeout()
 {
-    log->log(log_tag, "handle_disable_inactivity_timeout");
+    log->logDebug(log_tag, "handle_disable_inactivity_timeout");
 
     disallow_inactivity_timeout(InactivityTimeoutAllowance::client);
 
@@ -251,7 +251,7 @@ void repowerd::DefaultStateMachine::handle_set_inactivity_behavior(
     PowerSupply power_supply,
     std::chrono::milliseconds timeout)
 {
-    log->log(log_tag, "handle_set_inactivity_behavior(%s,%s,%ld)",
+    log->logDebug(log_tag, "handle_set_inactivity_behavior(%s,%s,%ld)",
              power_action_to_str(power_action).c_str(),
              power_supply_to_str(power_supply).c_str(),
              static_cast<long>(timeout.count()));
@@ -288,7 +288,7 @@ void repowerd::DefaultStateMachine::handle_set_inactivity_behavior(
 
 void repowerd::DefaultStateMachine::handle_lid_closed()
 {
-    log->log(log_tag, "handle_lid_closed()");
+    log->logDebug(log_tag, "handle_lid_closed()");
 
     lid_closed = true;
 
@@ -308,7 +308,7 @@ void repowerd::DefaultStateMachine::handle_lid_closed()
 
 void repowerd::DefaultStateMachine::handle_lid_open()
 {
-    log->log(log_tag, "handle_lid_open()");
+    log->logDebug(log_tag, "handle_lid_open()");
 
     lid_closed = false;
 
@@ -329,7 +329,7 @@ void repowerd::DefaultStateMachine::handle_lid_open()
 void repowerd::DefaultStateMachine::handle_set_lid_behavior(
     PowerAction power_action, PowerSupply power_supply)
 {
-    log->log(log_tag, "handle_set_lid_behavior(%s,%s)",
+    log->logDebug(log_tag, "handle_set_lid_behavior(%s,%s)",
              power_action_to_str(power_action).c_str(),
              power_supply_to_str(power_supply).c_str());
 
@@ -348,7 +348,7 @@ void repowerd::DefaultStateMachine::handle_set_lid_behavior(
 void repowerd::DefaultStateMachine::handle_set_critical_power_behavior(
     PowerAction power_action)
 {
-    log->log(log_tag, "handle_set_critical_power_behavior(%s)",
+    log->logDebug(log_tag, "handle_set_critical_power_behavior(%s)",
              power_action_to_str(power_action).c_str());
 
     if (power_action != PowerAction::suspend &&
@@ -362,7 +362,7 @@ void repowerd::DefaultStateMachine::handle_set_critical_power_behavior(
 
 void repowerd::DefaultStateMachine::handle_no_notification()
 {
-    log->log(log_tag, "handle_no_notification");
+    log->logDebug(log_tag, "handle_no_notification");
 
     if (display_power_mode == DisplayPowerMode::on)
     {
@@ -376,7 +376,7 @@ void repowerd::DefaultStateMachine::handle_no_notification()
 
 void repowerd::DefaultStateMachine::handle_notification()
 {
-    log->log(log_tag, "handle_notification");
+    log->logDebug(log_tag, "handle_notification");
 
     disallow_inactivity_timeout(InactivityTimeoutAllowance::notification);
 
@@ -401,7 +401,7 @@ void repowerd::DefaultStateMachine::handle_notification()
 
 void repowerd::DefaultStateMachine::handle_power_button_press()
 {
-    log->log(log_tag, "handle_power_button_press");
+    log->logDebug(log_tag, "handle_power_button_press");
 
     display_power_mode_at_power_button_press = display_power_mode;
 
@@ -423,7 +423,7 @@ void repowerd::DefaultStateMachine::handle_power_button_press()
 
 void repowerd::DefaultStateMachine::handle_power_button_release()
 {
-    log->log(log_tag, "handle_power_button_release");
+    log->logDebug(log_tag, "handle_power_button_release");
 
     if (power_button_long_press_detected)
     {
@@ -441,7 +441,7 @@ void repowerd::DefaultStateMachine::handle_power_button_release()
 
 void repowerd::DefaultStateMachine::handle_power_source_change()
 {
-    log->log(log_tag, "handle_power_source_change");
+    log->logDebug(log_tag, "handle_power_source_change");
 
     auto const is_on_battery = power_source->is_using_battery_power();
 
@@ -465,7 +465,7 @@ void repowerd::DefaultStateMachine::handle_power_source_change()
 
 void repowerd::DefaultStateMachine::handle_power_source_critical()
 {
-    log->log(log_tag, "handle_power_source_critical");
+    log->logDebug(log_tag, "handle_power_source_critical");
 
     if (critical_power_action == PowerAction::power_off)
         system_power_control->power_off();
@@ -475,7 +475,7 @@ void repowerd::DefaultStateMachine::handle_power_source_critical()
 
 void repowerd::DefaultStateMachine::handle_proximity_far()
 {
-    log->log(log_tag, "handle_proximity_far");
+    log->logDebug(log_tag, "handle_proximity_far");
 
     auto const use_reduced_timeout =
         is_proximity_enabled_only_until_far_event_or_notification_expiration();
@@ -497,7 +497,7 @@ void repowerd::DefaultStateMachine::handle_proximity_far()
 
 void repowerd::DefaultStateMachine::handle_proximity_near()
 {
-    log->log(log_tag, "handle_proximity_near");
+    log->logDebug(log_tag, "handle_proximity_near");
 
     if (display_power_mode == DisplayPowerMode::on)
         turn_off_display(DisplayPowerChangeReason::proximity);
@@ -505,7 +505,7 @@ void repowerd::DefaultStateMachine::handle_proximity_near()
 
 void repowerd::DefaultStateMachine::handle_user_activity_changing_power_state()
 {
-    log->log(log_tag, "handle_user_activity_changing_power_state");
+    log->logDebug(log_tag, "handle_user_activity_changing_power_state");
 
     if (display_power_mode == DisplayPowerMode::on)
     {
@@ -521,7 +521,7 @@ void repowerd::DefaultStateMachine::handle_user_activity_changing_power_state()
 
 void repowerd::DefaultStateMachine::handle_user_activity_extending_power_state()
 {
-    log->log(log_tag, "handle_user_activity_extending_power_state");
+    log->logDebug(log_tag, "handle_user_activity_extending_power_state");
 
     if (display_power_mode == DisplayPowerMode::on)
     {
@@ -533,7 +533,7 @@ void repowerd::DefaultStateMachine::handle_user_activity_extending_power_state()
 
 void repowerd::DefaultStateMachine::handle_set_normal_brightness_value(double value)
 {
-    log->log(log_tag, "handle_set_normal_brightness_value(%.2f)", value);
+    log->logDebug(log_tag, "handle_set_normal_brightness_value(%.2f)", value);
 
     normal_brightness_value = value;
 
@@ -544,7 +544,7 @@ void repowerd::DefaultStateMachine::handle_set_normal_brightness_value(double va
 
 void repowerd::DefaultStateMachine::handle_enable_autobrightness()
 {
-    log->log(log_tag, "enable_autobrightness");
+    log->logDebug(log_tag, "enable_autobrightness");
 
     autobrightness_enabled = true;
 
@@ -555,7 +555,7 @@ void repowerd::DefaultStateMachine::handle_enable_autobrightness()
 
 void repowerd::DefaultStateMachine::handle_disable_autobrightness()
 {
-    log->log(log_tag, "disable_autobrightness");
+    log->logDebug(log_tag, "disable_autobrightness");
 
     autobrightness_enabled = false;
 
@@ -564,9 +564,9 @@ void repowerd::DefaultStateMachine::handle_disable_autobrightness()
     brightness_control->disable_autobrightness();
 }
 
-void repowerd::DefaultStateMachine::handle_allow_suspend()
+void repowerd::DefaultStateMachine::handle_allow_suspend(std::string id)
 {
-    log->log(log_tag, "allow_suspend");
+    log->logDebug(log_tag, "allow_suspend(id=%s)", id.c_str());
 
     suspend_allowed = true;
 
@@ -578,9 +578,9 @@ void repowerd::DefaultStateMachine::handle_allow_suspend()
         suspend_when_allowed();
 }
 
-void repowerd::DefaultStateMachine::handle_disallow_suspend()
+void repowerd::DefaultStateMachine::handle_disallow_suspend(std::string id)
 {
-    log->log(log_tag, "disallow_suspend");
+    log->logDebug(log_tag, "disallow_suspend(id=%s)", id.c_str());
 
     suspend_allowed = false;
     cancel_suspend_delay_alarm();
@@ -589,14 +589,14 @@ void repowerd::DefaultStateMachine::handle_disallow_suspend()
 
 void repowerd::DefaultStateMachine::handle_system_resume()
 {
-    log->log(log_tag, "handle_system_resume");
+    log->logDebug(log_tag, "handle_system_resume");
 
     turn_on_display_with_normal_timeout(DisplayPowerChangeReason::activity);
 }
 
 void repowerd::DefaultStateMachine::start()
 {
-    log->log(log_tag, "start");
+    log->logDebug(log_tag, "start");
 
     auto const is_on_battery = power_source->is_using_battery_power();
 
@@ -612,7 +612,7 @@ void repowerd::DefaultStateMachine::start()
 
 void repowerd::DefaultStateMachine::pause()
 {
-    log->log(log_tag, "pause");
+    log->logDebug(log_tag, "pause");
 
     if (power_button_long_press_alarm_id != AlarmId::invalid)
     {
@@ -630,7 +630,7 @@ void repowerd::DefaultStateMachine::pause()
 
 void repowerd::DefaultStateMachine::resume()
 {
-    log->log(log_tag, "resume");
+    log->logDebug(log_tag, "resume");
 
     paused = false;
 
