@@ -18,6 +18,7 @@
 
 #include "default_daemon_config.h"
 #include "core/default_state_machine_factory.h"
+#include "src/core/double_tap_to_wake.h"
 #include "src/core/performance_booster.h"
 #include "src/core/proximity_sensor.h"
 
@@ -28,6 +29,7 @@
 #include "adapters/console_log.h"
 #include "adapters/default_state_machine_options.h"
 #include "adapters/event_loop_timer.h"
+#include "adapters/fs_double_tap_to_wake.h"
 #include "adapters/libsuspend_system_power_control.h"
 #include "adapters/light_sensor.h"
 #include "adapters/logind_session_tracker.h"
@@ -38,6 +40,7 @@
 #include "adapters/null_log.h"
 #include "adapters/ofono_voice_call_service.h"
 #include "adapters/real_chrono.h"
+#include "adapters/real_device_info.h"
 #include "adapters/real_filesystem.h"
 #include "adapters/real_temporary_suspend_inhibition.h"
 #include "adapters/repowerd_settings_service.h"
@@ -55,6 +58,13 @@
 #include "adapters/ubuntu_performance_booster.h"
 #include "adapters/ubuntu_proximity_sensor.h"
 #endif
+// Binder
+#ifdef REPOWERD_ENABLE_BINDER
+#include "adapters/binder_performance_booster.h"
+#endif
+// Sensorfw
+#include "adapters/sensorfw/sensorfw_light_sensor.h"
+#include "adapters/sensorfw/sensorfw_proximity_sensor.h"
 
 namespace
 {
@@ -167,8 +177,8 @@ repowerd::DefaultDaemonConfig::the_brightness_control()
     }
     catch (std::exception const& e)
     {
-        the_log()->log(log_tag, "Failed to create BrightnessControl: %s", e.what());
-        the_log()->log(log_tag, "Falling back to NullBrightnessControl");
+        the_log()->logWarning(log_tag, "Failed to create BrightnessControl: %s", e.what());
+        the_log()->logWarning(log_tag, "Falling back to NullBrightnessControl");
         brightness_control = std::make_shared<NullBrightnessControl>();
     }
 
@@ -223,7 +233,19 @@ repowerd::DefaultDaemonConfig::the_performance_booster()
     if (performance_booster)
         return performance_booster;
 
-#ifdef REPOWERD_ENABLE_HYBRIS
+#if defined(REPOWERD_ENABLE_BINDER)
+    try
+    {
+        performance_booster = std::make_shared<BinderPerformanceBooster>(
+            the_log());
+        return performance_booster;
+    }
+    catch (std::exception const& e)
+    {
+        the_log()->log(log_tag, "Failed to create BinderPerformanceBooster: %s", e.what());
+        the_log()->log(log_tag, "Falling back to NullPerformanceBooster");
+    }
+#elif defined(REPOWERD_ENABLE_HYBRIS)
     try
     {
         performance_booster = std::make_shared<UbuntuPerformanceBooster>(
@@ -232,8 +254,8 @@ repowerd::DefaultDaemonConfig::the_performance_booster()
     }
     catch (std::exception const& e)
     {
-        the_log()->log(log_tag, "Failed to create UbuntuPerformanceBooster: %s", e.what());
-        the_log()->log(log_tag, "Falling back to NullPerformanceBooster");
+        the_log()->logWarning(log_tag, "Failed to create UbuntuPerformanceBooster: %s", e.what());
+        the_log()->logWarning(log_tag, "Falling back to NullPerformanceBooster");
     }
 #endif
 
@@ -275,13 +297,24 @@ repowerd::DefaultDaemonConfig::the_proximity_sensor()
     }
     catch (std::exception const& e)
     {
-        the_log()->log(log_tag, "Failed to create UbuntuProximitySensor: %s", e.what());
-        the_log()->log(log_tag, "Falling back to NullProximitySensor");
+        the_log()->logWarning(log_tag, "Failed to create UbuntuProximitySensor: %s", e.what());
+        the_log()->logWarning(log_tag, "Trying SensorfwProximitySensor");
     }
-#else
-    the_log()->log(log_tag, "Built without ProximitySensor, Falling back to NullProximitySensor");
 #endif
 
+    try
+    {
+        proximity_sensor = std::make_shared<SensorfwProximitySensor>(
+            the_log(),
+            the_dbus_bus_address());
+        return proximity_sensor;
+    }
+    catch (std::exception const& e)
+    {
+        the_log()->logWarning(log_tag, "Failed to create SensorfwProximitySensor: %s", e.what());
+        the_log()->logWarning(log_tag, "Falling back to NullProximitySensor");
+    }
+
     proximity_sensor = std::make_shared<NullProximitySensor>();
     return proximity_sensor;
 
@@ -312,7 +345,9 @@ std::shared_ptr<repowerd::StateMachineOptions>
 repowerd::DefaultDaemonConfig::the_state_machine_options()
 {
     if (!state_machine_options)
-        state_machine_options = std::make_shared<DefaultStateMachineOptions>(*the_log());
+        state_machine_options = std::make_shared<DefaultStateMachineOptions>(
+            *the_log(),
+            the_device_info());
 
     return state_machine_options;
 }
@@ -329,8 +364,8 @@ repowerd::DefaultDaemonConfig::the_system_power_control()
         }
         catch (std::exception const& e)
         {
-            the_log()->log(log_tag, "Failed to create LibsuspendSystemPowerControl: %s", e.what());
-            the_log()->log(log_tag, "Trying LogindSystemPowerControl");
+            the_log()->logWarning(log_tag, "Failed to create LibsuspendSystemPowerControl: %s", e.what());
+            the_log()->logWarning(log_tag, "Trying LogindSystemPowerControl");
         }
 
         try
@@ -344,8 +379,8 @@ repowerd::DefaultDaemonConfig::the_system_power_control()
         }
         catch (std::exception const& e)
         {
-            the_log()->log(log_tag, "Failed to create LogindSystemPowerControl: %s", e.what());
-            the_log()->log(log_tag, "Falling back to NullSystemPowerControl");
+            the_log()->logWarning(log_tag, "Failed to create LogindSystemPowerControl: %s", e.what());
+            the_log()->logWarning(log_tag, "Falling back to NullSystemPowerControl");
             system_power_control = std::make_shared<NullSystemPowerControl>();
         }
     }
@@ -387,8 +422,8 @@ repowerd::DefaultDaemonConfig::the_backlight()
         }
         catch (std::exception const& e)
         {
-            the_log()->log(log_tag, "Failed to create AndroidBacklight: %s", e.what());
-            the_log()->log(log_tag, "Trying SysfsBacklight");
+            the_log()->logWarning(log_tag, "Failed to create AndroidBacklight: %s", e.what());
+            the_log()->logWarning(log_tag, "Trying SysfsBacklight");
         }
 #endif
 
@@ -402,7 +437,7 @@ repowerd::DefaultDaemonConfig::the_backlight()
         }
         catch (std::exception const& e)
         {
-            the_log()->log(log_tag, "Failed to create SyfsBacklight: %s", e.what());
+            the_log()->logWarning(log_tag, "Failed to create SyfsBacklight: %s", e.what());
             throw std::runtime_error("Failed to create backlight");
         }
     }
@@ -418,7 +453,7 @@ repowerd::DefaultDaemonConfig::the_backlight_brightness_control()
         auto const ab_log_env_cstr = getenv("REPOWERD_LOG_AUTOBRIGHTNESS");
         std::string const ab_log_env{ab_log_env_cstr ? ab_log_env_cstr : ""};
 
-        auto const ab_log = ab_log_env.empty() ? std::make_shared<NullLog>() : the_log();
+        auto const ab_log = ab_log_env.empty() ? std::make_shared<NullLog>(LogLevel::Debug) : the_log();
 
         backlight_brightness_control = std::make_shared<BacklightBrightnessControl>(
             the_backlight(),
@@ -443,8 +478,8 @@ repowerd::DefaultDaemonConfig::the_brightness_notification()
     }
     catch (std::exception const& e)
     {
-        the_log()->log(log_tag, "Failed to create BrightnessNotification: %s", e.what());
-        the_log()->log(log_tag, "Falling back to NullBrightnessNotification");
+        the_log()->logWarning(log_tag, "Failed to create BrightnessNotification: %s", e.what());
+        the_log()->logWarning(log_tag, "Falling back to NullBrightnessNotification");
         brightness_notification = std::make_shared<NullBrightnessNotification>();
     }
 
@@ -489,6 +524,7 @@ repowerd::DefaultDaemonConfig::the_device_config()
         device_config = std::make_shared<AndroidDeviceConfig>(
             the_log(),
             the_filesystem(),
+            the_device_info(),
             device_config_dirs);
     }
 
@@ -499,11 +535,25 @@ std::shared_ptr<repowerd::DeviceQuirks>
 repowerd::DefaultDaemonConfig::the_device_quirks()
 {
     if (!device_quirks)
-        device_quirks = std::make_shared<AndroidDeviceQuirks>(*the_log());
+        device_quirks = std::make_shared<AndroidDeviceQuirks>(
+            *the_log(),
+            the_device_info());
 
     return device_quirks;
 }
 
+std::shared_ptr<repowerd::DoubleTapToWake>
+repowerd::DefaultDaemonConfig::the_double_tap_to_waker()
+{
+    if (!double_tap_to_wake)
+    {
+        double_tap_to_wake = std::make_shared<FsDoubleTapToWake>(the_log(), the_filesystem());
+        the_log()->logDebug(log_tag, "Loaded FsDoubleTapToWake");
+    }
+
+    return double_tap_to_wake;
+}
+
 std::shared_ptr<repowerd::Filesystem>
 repowerd::DefaultDaemonConfig::the_filesystem()
 {
@@ -527,13 +577,24 @@ repowerd::DefaultDaemonConfig::the_light_sensor()
     }
     catch (std::exception const& e)
     {
-        the_log()->log(log_tag, "Failed to create UbuntuLightSensor: %s", e.what());
-        the_log()->log(log_tag, "Falling back to NullLightSensor");
+        the_log()->logWarning(log_tag, "Failed to create UbuntuLightSensor: %s", e.what());
+        the_log()->logWarning(log_tag, "Trying SensorfwLightSensor");
     }
-#else
-    the_log()->log(log_tag, "Built without LightSensor, Falling back to NullLightSensor");
 #endif
 
+    try
+    {
+        light_sensor = std::make_shared<SensorfwLightSensor>(
+            the_log(),
+            the_dbus_bus_address());
+        return light_sensor;
+    }
+    catch (std::exception const& e)
+    {
+        the_log()->logWarning(log_tag, "Failed to create SensorfwLightSensor: %s", e.what());
+        the_log()->logWarning(log_tag, "Falling back to NullLightSensor");
+    }
+
     light_sensor = std::make_shared<NullLightSensor>();
     return light_sensor;
 }
@@ -572,14 +633,24 @@ repowerd::DefaultDaemonConfig::the_log()
 {
     if (!log)
     {
+        auto const log_threshold_cstr = getenv("REPOWERD_LOG_LEVEL");
+        std::string const log_threshold_str{log_threshold_cstr ? log_threshold_cstr : ""};
+        repowerd::LogLevel log_threshold{LogLevel::Info};
+        if (log_threshold_str == "debug")
+            log_threshold = LogLevel::Debug;
+        else if (log_threshold_str == "info")
+            log_threshold = LogLevel::Info;
+        else if (log_threshold_str == "info")
+            log_threshold = LogLevel::Warning;
+
         auto const log_env_cstr = getenv("REPOWERD_LOG");
         std::string const log_env{log_env_cstr ? log_env_cstr : ""};
         if (log_env == "console")
-            log = std::make_shared<ConsoleLog>();
+            log = std::make_shared<ConsoleLog>(log_threshold);
         else if (log_env == "null")
-            log = std::make_shared<NullLog>();
+            log = std::make_shared<NullLog>(log_threshold);
         else
-            log = std::make_shared<SyslogLog>();
+            log = std::make_shared<SyslogLog>(log_threshold);
     }
     return log;
 }
@@ -606,6 +677,7 @@ repowerd::DefaultDaemonConfig::the_unity_screen_service()
             the_brightness_notification(),
             the_log(),
             the_temporary_suspend_inhibition(),
+            the_double_tap_to_waker(),
             *the_device_config(),
             the_dbus_bus_address());
     }
@@ -647,8 +719,8 @@ repowerd::DefaultDaemonConfig::the_wakeup_service()
     }
     catch (std::exception const& e)
     {
-        the_log()->log(log_tag, "Failed to create DevAlarmWakeupService: %s", e.what());
-        the_log()->log(log_tag, "Trying TimerfdWakeupService");
+        the_log()->logWarning(log_tag, "Failed to create DevAlarmWakeupService: %s", e.what());
+        the_log()->logWarning(log_tag, "Trying TimerfdWakeupService");
     }
 #endif
 
@@ -657,3 +729,12 @@ repowerd::DefaultDaemonConfig::the_wakeup_service()
 
     return wakeup_service;
 }
+
+std::shared_ptr<repowerd::DeviceInfo>
+repowerd::DefaultDaemonConfig::the_device_info()
+{
+    if (!device_info)
+        device_info = std::make_shared<repowerd::RealDeviceInfo>();
+
+    return device_info;
+}
