@@ -48,9 +48,18 @@ namespace
 class FakeBacklight : public repowerd::Backlight
 {
 public:
+
+    FakeBacklight(std::shared_ptr<rt::FakeChrono> const& chrono)
+    : chrono{chrono}
+    {
+    }
+
     void set_brightness(double v) override
     {
         brightness_history.push_back(v);
+        // We have to fake-sleep here since the dimming code measures
+        // actual execution time of this method
+        chrono->sleep_for(2500us);
     }
 
     double get_brightness() override
@@ -91,6 +100,8 @@ public:
 
     double const starting_brightness = 0.5;
     std::vector<double> brightness_history{starting_brightness};
+    std::shared_ptr<rt::FakeChrono> const chrono;
+
 };
 
 class FakeLightSensor : public repowerd::LightSensor
@@ -183,11 +194,11 @@ struct ABacklightBrightnessControl : Test
     }
 
     rt::FakeDeviceConfig fake_device_config;
-    FakeBacklight backlight;
     FakeLightSensor light_sensor;
     FakeAutobrightnessAlgorithm autobrightness_algorithm;
     rt::FakeChrono fake_chrono;
-    rt::FakeLog fake_log;
+    FakeBacklight backlight{rt::fake_shared(fake_chrono)};
+    rt::FakeLog fake_log{repowerd::LogLevel::Debug};
     rt::FakeDeviceQuirks fake_device_quirks;
     repowerd::BacklightBrightnessControl brightness_control{
         rt::fake_shared(backlight), 
@@ -211,7 +222,7 @@ struct ABacklightBrightnessControl : Test
 
 MATCHER_P(IsAbout, a, "")
 {
-    return arg >= a && arg <= a + 10ms;
+    return arg >= a - 10ms && arg <= a + 10ms;
 }
 
 }
@@ -287,16 +298,16 @@ TEST_F(ABacklightBrightnessControl, transitions_smoothly_between_brightness_valu
 }
 
 TEST_F(ABacklightBrightnessControl,
-       transitions_between_zero_and_non_zero_brightness_in_100ms)
+       transitions_between_zero_and_non_zero_brightness_in_250ms)
 {
     brightness_control.set_off_brightness();
 
     EXPECT_THAT(fake_chrono_duration_of([&]{brightness_control.set_normal_brightness();}),
-                IsAbout(100ms));
+                IsAbout(250ms));
     EXPECT_THAT(fake_chrono_duration_of([&]{brightness_control.set_off_brightness();}),
-                IsAbout(100ms));
+                IsAbout(250ms));
     EXPECT_THAT(fake_chrono_duration_of([&]{brightness_control.set_dim_brightness();}),
-                IsAbout(100ms));
+                IsAbout(250ms));
 }
 
 TEST_F(ABacklightBrightnessControl,
@@ -600,7 +611,7 @@ TEST_F(ABacklightBrightnessControl, logs_brightness_transition)
     brightness_control.set_off_brightness();
 
     EXPECT_TRUE(fake_log.contains_line(
-        {std::to_string(normal_percent).substr(0, 4), "0.00", "steps"}));
+        {std::to_string(normal_percent).substr(0, 4), "0.00", "transition time"}));
     EXPECT_TRUE(fake_log.contains_line(
         {std::to_string(normal_percent).substr(0, 4), "0.00", "done"}));
 }
