@@ -25,6 +25,8 @@
 #include "dbus_client.h"
 #include "fake_brightness_notification.h"
 #include "fake_device_config.h"
+#include "fake_double_tap_to_wake.h"
+#include "fake_filesystem.h"
 #include "fake_log.h"
 #include "fake_wakeup_service.h"
 
@@ -211,14 +213,19 @@ struct APowerdService : testing::Test
     rt::DBusBus bus;
     rt::FakeBrightnessNotification fake_brightness_notification;
     rt::FakeDeviceConfig fake_device_config;
-    rt::FakeLog fake_log;
+    rt::FakeFilesystem fake_filesystem;
+    rt::FakeLog fake_log{repowerd::LogLevel::Debug};
     rt::FakeWakeupService fake_wakeup_service;
+    rt::FakeDoubleTapToWake fake_double_tap_to_wake{
+        rt::fake_shared(fake_log),
+        rt::fake_shared(fake_filesystem)};
     NiceMock<MockTemporarySuspendInhibition> mock_temporary_suspend_inhibition;
     repowerd::UnityScreenService unity_screen_service{
         rt::fake_shared(fake_wakeup_service),
         rt::fake_shared(fake_brightness_notification),
         rt::fake_shared(fake_log),
         rt::fake_shared(mock_temporary_suspend_inhibition),
+        rt::fake_shared(fake_double_tap_to_wake),
         fake_device_config,
         bus.address()};
     RepowerdDBusClient client{bus.address()};
