@@ -19,6 +19,8 @@
 #include "dbus_bus.h"
 #include "fake_brightness_notification.h"
 #include "fake_device_config.h"
+#include "fake_double_tap_to_wake.h"
+#include "fake_filesystem.h"
 #include "fake_log.h"
 #include "fake_wakeup_service.h"
 #include "unity_screen_dbus_client.h"
@@ -111,14 +113,19 @@ struct AUnityScreenService : testing::Test
     rt::DBusBus bus;
     rt::FakeBrightnessNotification fake_brightness_notification;
     rt::FakeDeviceConfig fake_device_config;
-    rt::FakeLog fake_log;
+    rt::FakeFilesystem fake_filesystem;
+    rt::FakeLog fake_log{repowerd::LogLevel::Debug};
     rt::FakeWakeupService fake_wakeup_service;
+    rt::FakeDoubleTapToWake fake_double_tap_to_wake{
+        rt::fake_shared(fake_log),
+        rt::fake_shared(fake_filesystem)};
     NullTemporarySuspendInhibition null_temporary_suspend_inhibition;
     repowerd::UnityScreenService service{
         rt::fake_shared(fake_wakeup_service),
         rt::fake_shared(fake_brightness_notification),
         rt::fake_shared(fake_log),
         rt::fake_shared(null_temporary_suspend_inhibition),
+        rt::fake_shared(fake_double_tap_to_wake),
         fake_device_config,
         bus.address()};
     rt::UnityScreenDBusClient client{bus.address()};
