@@ -98,8 +98,8 @@ struct MockStateMachine : public repowerd::StateMachine
 
     MOCK_METHOD0(handle_system_resume, void());
 
-    MOCK_METHOD0(handle_allow_suspend, void());
-    MOCK_METHOD0(handle_disallow_suspend, void());
+    MOCK_METHOD1(handle_allow_suspend, void(std::string));
+    MOCK_METHOD1(handle_disallow_suspend, void(std::string));
 
     void start()
     {
@@ -590,7 +590,7 @@ TEST_F(ADaemon, notifies_state_machine_of_allow_suspend_handler)
 {
     start_daemon();
 
-    EXPECT_CALL(*config.the_mock_state_machine(), handle_allow_suspend());
+    EXPECT_CALL(*config.the_mock_state_machine(), handle_allow_suspend("id"));
 
     config.the_fake_client_requests()->emit_allow_suspend("id");
 }
@@ -599,8 +599,8 @@ TEST_F(ADaemon, notifies_inactive_state_machine_of_allow_suspend)
 {
     start_daemon_with_second_session_active();
 
-    EXPECT_CALL(*config.the_mock_state_machine(0), handle_allow_suspend());
-    EXPECT_CALL(*config.the_mock_state_machine(1), handle_allow_suspend()).Times(0);
+    EXPECT_CALL(*config.the_mock_state_machine(0), handle_allow_suspend("id"));
+    EXPECT_CALL(*config.the_mock_state_machine(1), handle_allow_suspend("id")).Times(0);
     config.the_fake_client_requests()->emit_allow_suspend("id");
 }
 
@@ -621,7 +621,7 @@ TEST_F(ADaemon, notifies_state_machine_of_disallow_suspend_handler)
 {
     start_daemon();
 
-    EXPECT_CALL(*config.the_mock_state_machine(), handle_disallow_suspend());
+    EXPECT_CALL(*config.the_mock_state_machine(), handle_disallow_suspend("id"));
 
     config.the_fake_client_requests()->emit_disallow_suspend("id");
 }
@@ -630,8 +630,8 @@ TEST_F(ADaemon, notifies_inactive_state_machine_of_disallow_suspend)
 {
     start_daemon_with_second_session_active();
 
-    EXPECT_CALL(*config.the_mock_state_machine(0), handle_disallow_suspend());
-    EXPECT_CALL(*config.the_mock_state_machine(1), handle_disallow_suspend()).Times(0);
+    EXPECT_CALL(*config.the_mock_state_machine(0), handle_disallow_suspend("id"));
+    EXPECT_CALL(*config.the_mock_state_machine(1), handle_disallow_suspend("id")).Times(0);
     config.the_fake_client_requests()->emit_disallow_suspend("id");
 }
 
@@ -1118,8 +1118,8 @@ TEST_F(ADaemon, notifies_all_state_machines_of_system_allow_suspend)
 {
     start_daemon_with_second_session_active();
 
-    EXPECT_CALL(*config.the_mock_state_machine(0), handle_allow_suspend());
-    EXPECT_CALL(*config.the_mock_state_machine(1), handle_allow_suspend());
+    EXPECT_CALL(*config.the_mock_state_machine(0), handle_allow_suspend("FakeSystemPowerControl"));
+    EXPECT_CALL(*config.the_mock_state_machine(1), handle_allow_suspend("FakeSystemPowerControl"));
 
     config.the_fake_system_power_control()->emit_system_allow_suspend();
 }
@@ -1141,8 +1141,8 @@ TEST_F(ADaemon, notifies_all_state_machines_of_system_disallow_suspend)
 {
     start_daemon_with_second_session_active();
 
-    EXPECT_CALL(*config.the_mock_state_machine(0), handle_disallow_suspend());
-    EXPECT_CALL(*config.the_mock_state_machine(1), handle_disallow_suspend());
+    EXPECT_CALL(*config.the_mock_state_machine(0), handle_disallow_suspend("FakeSystemPowerControl"));
+    EXPECT_CALL(*config.the_mock_state_machine(1), handle_disallow_suspend("FakeSystemPowerControl"));
 
     config.the_fake_system_power_control()->emit_system_disallow_suspend();
 }
